#       Source.bash
#
#       This file is part of Zenpakt

#       Copyright 2011 Anshul Narula aka sunny <sunny_delhi18@yahoo.com>
#
#       Zenpakt is free software; you can redistribute it and/or modify
#       it under the terms of the GNU General Public License as published by
#       the Free Software Foundation; either version 2 of the License, or
#       (at your option) any later version.
#
#       This program is distributed in the hope that it will be useful,
#       but WITHOUT ANY WARRANTY; without even the implied warranty of
#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#       GNU General Public License for more details.
#
#       You should have received a copy of the GNU General Public License
#       along with this program; if not, write to the Free Software
#       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#       MA 02110-1301, USA.

#TO DO:rename it to something less confusing (e.g include)

$DOC

=========
 include
=========

-------------------------------
 Source Zenpakt function files
-------------------------------

SYNOPSIS
--------

 **include** *file* [ *arg...* ]

DESCRIPTION
-----------

Source the given *file* using the value set by ZENPAKT_INCLUDE_DIR as the root
directory.Any more arguments are passed as argument to the file being sourced.

$ENDDOC

$$

include() {
  #Bash looks through the PATH for filename's with no slashes and when in non
  #posix mode it doesnot even look through the current directory if file is not
  #found in PATH. So, we can set PATH for a while to the path that we want, but
  #this means the same PATH will be available for sourced file and if it tries
  #to execute a command, things may not work as expected.Also, if file contains
  #one or more /'s we need to look ourselves.

  if [[ ${ZENPAKT_INCLUDE_DIR:-:} != *:* ]] ; then
    . "$ZENPAKT_INCLUDE_DIR/$1" "${@:2}"
  else
    #if ZENPAKT_INCLUDE_DIR is null or unset, the loop will not be executed and
    #we will return 1. If it is set and no files are found, we will still return
    #1. If a file is found we return what source returns.
    local paths path
    IFS=: read -ra paths <<<"$ZENPAKT_INCLUDE_DIR"
    for path in "${paths[@]}" ; do
      if [[ -f $path/$1 ]] ; then
        . "$path/$1" "${@:2}"
        return $?
      fi
    done
    return 1
  fi
}
